@@ -1,7 +1,7 @@
 package Perinci::Exporter;
 
-our $DATE = '2019-08-15'; # DATE
-our $VERSION = '0.081'; # VERSION
+our $DATE = '2019-08-18'; # DATE
+our $VERSION = '0.082'; # VERSION
 
 # IFUNBUILT
 # use strict 'subs', 'vars';
@@ -336,7 +336,7 @@ Perinci::Exporter - An exporter that groks Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.081 of Perinci::Exporter (from Perl distribution Perinci-Exporter), released on 2019-08-15.
+This document describes version 0.082 of Perinci::Exporter (from Perl distribution Perinci-Exporter), released on 2019-08-18.
 
 =head1 SYNOPSIS
 
@@ -407,6 +407,16 @@ Importing:
 
  # XXX other per-import options
 
+ # import option: set prefix/suffix for all imports. the statement below will
+ # import foo_f1_bar and foo_f2_bar.
+ use YourModule 'f1', 'f2', -prefix=>'foo', -suffix=>'bar';
+
+ # import option: define behavior when an import clashes with existing symbol.
+ # the default is 'force' which, like Exporter, will force importing anyway
+ # without warning, overriding existing symbol. another option is to 'bail'
+ # (die).
+ use YourModule 'f1', 'f2', -on_clash=>'die';
+
 =head1 DESCRIPTION
 
 Perinci::Exporter is an exporter which can utilize information from L<Rinci>
